import robinhood from "./liquidity-snapshot.json";
import ethereum from "./liquidity-snapshot-ethereum.json";
import base from "./liquidity-snapshot-base.json";
import type { SnapshotSet } from "./liquidity-set";
export const bundledSnapshots = { robinhood, ethereum, base } as SnapshotSet;
