CREATE TABLE `liquidity_collectors` (
	`chain` text PRIMARY KEY NOT NULL,
	`state` text,
	`provider` text DEFAULT 'geckoterminal' NOT NULL,
	`lease_until` integer DEFAULT 0 NOT NULL,
	`lease_token` text,
	`next_attempt_at` integer DEFAULT 0 NOT NULL,
	`failures` integer DEFAULT 0 NOT NULL,
	`last_status` integer DEFAULT 0 NOT NULL,
	`last_attempt_at` integer DEFAULT 0 NOT NULL,
	`last_success_at` integer DEFAULT 0 NOT NULL
);
