import type { Language } from "./i18n";
const words: Record<Language, string[]> = {
  en: ["Chain", "Robinhood · Ethereum L1 · Base", "Top 80 pools by 24h volume · every asset in the sample", "Checking for newer data…", "No newer snapshot yet. Retrying automatically.", "Updated with newer data.", "Same ticker, different address. These assets are kept separate.", "Native ETH. Protocol address aliases are combined; WETH remains separate.", "Source", "Data coverage"],
  zh: ["区块链", "Robinhood · Ethereum L1 · Base", "24 小时交易量排名前 80 的池 · 包含样本中所有资产", "正在检查新数据…", "暂无更新快照，将自动重试。", "已载入更新数据。", "代码相同，地址不同，因此分别显示。", "原生 ETH；索引器将零地址标记为 WETH。", "源码", "数据范围"],
  es: ["Cadena", "Robinhood · Ethereum L1 · Base", "80 pools por volumen de 24 h · todos sus activos", "Buscando datos nuevos…", "Aún no hay datos nuevos. Reintentando automáticamente.", "Datos nuevos cargados.", "Mismo ticker, distinta dirección. Son activos separados.", "ETH nativo; el índice etiqueta la dirección cero como WETH.", "Código", "Cobertura"],
  ja: ["チェーン", "Robinhood · Ethereum L1 · Base", "24時間出来高上位80プール・含まれる全資産", "新しいデータを確認中…", "新しいデータはありません。自動で再試行します。", "新しいデータに更新しました。", "同じティッカーでもアドレスが異なるため別々に表示します。", "ネイティブETH。インデクサーはゼロアドレスをWETHと表記します。", "ソース", "データ範囲"],
  ko: ["체인", "Robinhood · Ethereum L1 · Base", "24시간 거래량 상위 80개 풀 · 포함된 모든 자산", "새 데이터 확인 중…", "아직 새 데이터가 없습니다. 자동으로 재시도합니다.", "새 데이터로 업데이트했습니다.", "티커는 같지만 주소가 달라 별도로 표시합니다.", "네이티브 ETH입니다. 인덱서는 제로 주소를 WETH로 표시합니다.", "소스", "데이터 범위"],
  fr: ["Chaîne", "Robinhood · Ethereum L1 · Base", "80 pools par volume sur 24 h · tous leurs actifs", "Recherche de données récentes…", "Pas de nouvel instantané. Nouvelle tentative automatique.", "Données récentes chargées.", "Même ticker, adresses différentes : actifs distincts.", "ETH natif ; l’indexeur nomme WETH l’entrée à l’adresse zéro.", "Source", "Couverture"],
  pt: ["Rede", "Robinhood · Ethereum L1 · Base", "80 pools por volume de 24 h · todos os seus ativos", "Buscando dados novos…", "Ainda sem novos dados. Nova tentativa automática.", "Dados novos carregados.", "Mesmo ticker, endereços diferentes. Ativos separados.", "ETH nativo; o indexador chama a entrada de endereço zero de WETH.", "Código", "Cobertura"],
  de: ["Chain", "Robinhood · Ethereum L1 · Base", "80 Pools nach 24h-Volumen · alle enthaltenen Assets", "Suche nach neueren Daten…", "Noch kein neuer Stand. Automatischer Wiederholungsversuch.", "Neuere Daten geladen.", "Gleicher Ticker, andere Adresse: separate Assets.", "Natives ETH; der Indexer nennt den Eintrag der Nulladresse WETH.", "Quellcode", "Abdeckung"],
};
export const chainCopy = Object.fromEntries(Object.entries(words).map(([lang, w]) => [lang, { chain: w[0], available: w[1], universe: w[2], checking: w[3], unchanged: w[4], updated: w[5], duplicate: w[6], native: w[7], source: w[8], coverage: w[9] }])) as Record<Language, { chain: string; available: string; universe: string; checking: string; unchanged: string; updated: string; duplicate: string; native: string; source: string; coverage: string }>;

const refreshMessages: Record<Language, [string, string, string]> = {
  en: ["Provider rate limited. Retrying automatically.", "Collecting the latest pools…", "Feed temporarily unavailable. Retrying automatically."],
  zh: ["数据源限流，将自动重试。", "正在收集最新流动性池…", "数据源暂不可用，将自动重试。"],
  es: ["Límite del proveedor. Reintento automático.", "Recopilando los pools más recientes…", "Datos no disponibles temporalmente. Reintento automático."],
  ja: ["データ提供元の制限により自動再試行します。", "最新のプールデータを取得中…", "データを一時的に取得できません。自動で再試行します。"],
  ko: ["제공업체 요청 제한. 자동 재시도합니다.", "최신 풀 데이터를 수집 중…", "데이터를 일시적으로 사용할 수 없습니다. 자동 재시도합니다."],
  fr: ["Limite du fournisseur. Nouvelle tentative automatique.", "Collecte des pools récents…", "Données indisponibles. Nouvelle tentative automatique."],
  pt: ["Limite do provedor. Nova tentativa automática.", "Coletando os pools mais recentes…", "Dados indisponíveis. Nova tentativa automática."],
  de: ["Anbieter begrenzt Anfragen. Automatischer Wiederholungsversuch.", "Aktuelle Pooldaten werden abgerufen…", "Daten vorübergehend nicht verfügbar. Automatischer Wiederholungsversuch."],
};
export const feedCopy = Object.fromEntries(Object.entries(refreshMessages).map(([lang, w]) => [lang, { limited: w[0], collecting: w[1], unavailable: w[2] }])) as Record<Language, { limited: string; collecting: string; unavailable: string }>;
