/** Provider network IDs are independent of application IDs and token symbols. */
export const CHAINS = [
  { id: "robinhood", name: "Robinhood", network: "robinhood", nativeSymbol: "ETH", poolPages: 4, poolPageSize: 20, poolSort: "h24_volume_usd_desc", explorer: "https://www.geckoterminal.com/robinhood" },
  { id: "ethereum", name: "Ethereum L1", network: "eth", nativeSymbol: "ETH", poolPages: 4, poolPageSize: 20, poolSort: "h24_volume_usd_desc", explorer: "https://www.geckoterminal.com/eth" },
  { id: "base", name: "Base", network: "base", nativeSymbol: "ETH", poolPages: 4, poolPageSize: 20, poolSort: "h24_volume_usd_desc", explorer: "https://www.geckoterminal.com/base" },
] as const;
export type ChainId = typeof CHAINS[number]["id"];
export const DEFAULT_CHAIN = CHAINS[0];
export function getChain(id: string) { return CHAINS.find(chain => chain.id === id); }
