/** Workers for Platforms disables caches.default; named caches are isolated per site. */
export async function edgeCache(): Promise<Cache | undefined> {
  try { return await globalThis.caches?.open("amm-liquidity-v4"); }
  catch { return undefined; }
}
