// A complete sweep can span several observations. The displayed age is always
// the oldest observation in that sweep, including time spent in provider caches.
export const FRESH_MS = 180_000;
export const DISCOVERY_MS = 15 * 60_000;
export type FeedStatus = {
  provider: string;
  state: "healthy" | "collecting" | "rate-limited" | "unavailable";
  nextAttemptAt: string;
  requestIntervalSeconds: number;
  completed: number;
  total: number;
  universeUpdatedAt: string | null;
};
