export const SITE_URL = "https://amm-correlated-pairs-liquidity.ryan-berckmans.chatgpt.site";
export const REPOSITORY_NAME = "amm-correlated-pairs-liquidity";
export const SITE_NAME = "AMM Correlated-Pairs Liquidity";
export const REPOSITORY_PATH = `/${REPOSITORY_NAME}.git`;
export const CLONE_COMMAND = `git clone ${SITE_URL}${REPOSITORY_PATH}`;

export const SOCIAL_IMAGE = { url: `${SITE_URL}/og.png`, width: 1730, height: 909, type: "image/png", alt: "AMM Correlated Pairs — Robinhood, Ethereum, and Base open-source liquidity map" };
