import { SitePage } from "./site-page";
import { getChain, DEFAULT_CHAIN } from "@/lib/chains";
export default async function Home({ searchParams }: { searchParams: Promise<{ chain?: string }> }) {
  const query = await searchParams;
  return <SitePage language="en" chain={getChain(query.chain ?? "")?.id ?? DEFAULT_CHAIN.id} />;
}
