@import "tailwindcss";
@import "tw-animate-css";
@import "../vendor/shadcn-tailwind-4.13.0.css";
@source inline("scrollbar-thin scrollbar-none scrollbar-gutter-stable scroll-fade-b shimmer");
@utility scrollbar-thin { scrollbar-width: thin; }
@utility scrollbar-none { scrollbar-width: none; &::-webkit-scrollbar { display: none; } }
@utility scrollbar-gutter-stable { scrollbar-gutter: stable; }

:root {
  --background: #f4f5f6; --foreground: #1c2330; --card: #ffffff; --card-foreground: #1c2330;
  --popover: #ffffff; --popover-foreground: #1c2330; --primary: #18232e; --primary-foreground: #ffffff;
  --secondary: #edf0f3; --secondary-foreground: #243443; --muted: #edf0f3; --muted-foreground: #626d7a;
  --accent: #eef2f5; --accent-foreground: #1c2330; --destructive: #cc334d;
  --border: #dee3e7; --input: #dee3e7; --ring: #119b79; --radius: .75rem;
}
@theme inline {
  --color-background: var(--background); --color-foreground: var(--foreground); --color-card: var(--card);
  --color-card-foreground: var(--card-foreground); --color-popover: var(--popover); --color-popover-foreground: var(--popover-foreground);
  --color-primary: var(--primary); --color-primary-foreground: var(--primary-foreground); --color-secondary: var(--secondary);
  --color-secondary-foreground: var(--secondary-foreground); --color-muted: var(--muted); --color-muted-foreground: var(--muted-foreground);
  --color-accent: var(--accent); --color-accent-foreground: var(--accent-foreground); --color-destructive: var(--destructive);
  --color-border: var(--border); --color-input: var(--input); --color-ring: var(--ring);
  --radius-sm: calc(var(--radius) - 4px); --radius-md: calc(var(--radius) - 2px); --radius-lg: var(--radius); --radius-xl: calc(var(--radius) + 4px);
  --font-sans: "Inter", "Noto Sans", "Noto Sans SC", ui-sans-serif, -apple-system, BlinkMacSystemFont, "Segoe UI", sans-serif;
}
* { box-sizing: border-box; }
html { background: var(--background); scroll-behavior: smooth; scroll-padding-top: 20px; }
body { margin: 0; color: var(--foreground); font-family: var(--font-sans); -webkit-font-smoothing: antialiased; }
button, a { -webkit-tap-highlight-color: transparent; }
button { font: inherit; cursor: pointer; }
button:disabled { cursor: default; }
button:focus-visible, a:focus-visible, summary:focus-visible, code:focus-visible { outline: 2px solid #119b79; outline-offset: 4px; }
a { color: inherit; text-decoration: none; }
::selection { color: #133e32; background: #c7efe1; }
.shell { width: min(100% - 64px, 1600px); margin: 0 auto; padding: 22px 0 24px; }
.topbar { display: flex; align-items: center; justify-content: space-between; gap: 20px; padding-bottom: 18px; border-bottom: 1px solid #dce2e6; }
.identity { display: flex; align-items: center; gap: 16px; min-width: 0; }
.brand-mark { position: relative; flex: 0 0 45px; width: 45px; height: 45px; color: #119b79; }
.brand-mark::before, .brand-mark::after { content: ""; position: absolute; left: 8px; top: 21px; width: 30px; height: 2px; background: currentColor; transform: rotate(-38deg); }
.brand-mark::after { top: 25px; transform: rotate(40deg); }
.brand-mark span { position: absolute; width: 12px; height: 12px; border: 3px solid currentColor; background: var(--background); border-radius: 50%; z-index: 1; }
.brand-mark span:nth-child(1) { left: 1px; top: 17px; width: 16px; height: 16px; }
.brand-mark span:nth-child(2) { right: 0; top: 2px; }
.brand-mark span:nth-child(3) { right: 0; bottom: 1px; }
.identity p { margin: 0 0 6px; font-size: .75rem; font-weight: 650; color: #65717c; letter-spacing: .09em; }
.identity p span { margin: 0 9px; color: #b2bbc1; }
.identity h1 { margin: 0; font-size: clamp(1.65rem, 2.7vw, 2.45rem); font-weight: 630; letter-spacing: -.055em; line-height: 1.05; }
.title-dot { color: #0e9c78; }
.top-actions { display: flex; align-items: center; gap: 9px; flex-shrink: 0; }
.chain-row { display: flex; align-items: center; flex-wrap: wrap; gap: 10px 18px; padding: 14px 0 0; }
.chain-trigger { width: 155px !important; height: 40px !important; background: white !important; font-size: .875rem !important; }
.chain-mark { display: grid; place-items: center; width: 21px; height: 21px; border-radius: 6px; color: #075f47; background: #d9f5e9; font-size: .75rem; font-weight: 750; }
.chain-availability { max-width: 250px; margin: 6px 8px; color: var(--muted-foreground); font-size: .8125rem; line-height: 1.4; }
.coverage-label { color: var(--muted-foreground); font-size: .8125rem; }
.coverage-label:hover { text-decoration: underline; }
.refresh-result { flex: 1; color: #53697a; font-size: .8125rem; text-align: right; }
.identity-note { color: var(--muted-foreground); font-size: .8125rem; line-height: 1.5; margin: 12px 0 0; }
.source-revision { font-family: ui-monospace, monospace; }
.feed-state { display: flex; flex-direction: column; align-items: flex-end; gap: 4px; }
.feed-state time { color: #78828e; font-size: .75rem; line-height: 1.2; }
.live-badge { display: inline-flex; align-items: center; gap: 6px; color: #087755; font-size: .75rem; font-weight: 760; letter-spacing: .05em; }
.live-badge i { width: 6px; height: 6px; border-radius: 100%; background: currentColor; box-shadow: 0 0 0 3px #0d9e7614; }
.live-badge.is-stale { color: #9a691c; }
.live-badge.is-stale i { box-shadow: none; }
.refresh-button { width: 38px; height: 38px; color: #64717d; }
.language-trigger { min-width: 120px; height: 40px !important; padding: 0 10px !important; border: 1px solid #d7dfe4 !important; border-radius: 8px !important; background: transparent !important; font-size: .875rem !important; box-shadow: none !important; }
.language-trigger svg { width: 16px; height: 16px; }
.metrics { display: grid; grid-template-columns: 1.1fr 1.1fr 1fr 1fr; padding: 18px 0 17px; }
.metric { padding-left: 30px; border-left: 1px solid #dce2e6; }
.metric:first-child { padding-left: 0; border-left: 0; }
.metric > span { color: #65717d; font-size: .875rem; }
.metric strong { display: flex; align-items: center; gap: 10px; margin: 7px 0 5px; font-size: clamp(1.5rem, 2.7vw, 2.35rem); font-weight: 590; letter-spacing: -.055em; font-variant-numeric: tabular-nums; line-height: 1.08; }
.metric strong svg { width: 18px; height: 18px; color: #8b98a4; }
.metric small { font-size: .75rem; color: #7a8691; }
.fork-bar { display: flex; align-items: center; gap: 14px; min-height: 44px; border: 1px solid #dae2e5; border-radius: 8px; background: #edf1f2; padding: 0 6px 0 13px; margin-bottom: 21px; }
.fork-label { display: flex; align-items: center; flex-shrink: 0; gap: 8px; font-size: .8125rem; font-weight: 650; }
.fork-label svg { width: 15px; height: 15px; color: #138868; }
.license-tag { font-family: ui-monospace, monospace; font-size: .75rem; color: #818f98; font-weight: 400; border-left: 1px solid #ccd7dd; padding-left: 10px; margin-left: 2px; }
.fork-bar code { display: block; flex: 1; min-width: 0; overflow: auto; white-space: nowrap; scrollbar-width: none; color: #62717e; font-size: .75rem; padding: 10px 0; }
.fork-bar button { display: flex; justify-content: center; align-items: center; gap: 6px; flex-shrink: 0; min-width: 64px; height: 32px; padding: 0 9px; border: 0; border-radius: 5px; background: #fff; color: #425461; box-shadow: 0 1px 3px #17262f08; font-size: .75rem; font-weight: 600; }
.fork-bar button:hover { color: #0d8565; background: #fbfffd; }
.fork-bar button svg { width: 14px; height: 14px; }
.workspace { display: grid; grid-template-columns: minmax(0, 1fr) 300px; gap: 20px; align-items: stretch; }
.network-card, .focus-card, .venues-card { border: 1px solid #dce2e7; background: #fff; border-radius: 14px; box-shadow: 0 4px 18px #192f4503; }
.network-card { overflow: hidden; min-width: 0; }
.network-head { padding: 20px 22px 12px; display: flex; justify-content: space-between; align-items: center; gap: 14px; }
.section-kicker { color: #88949d; letter-spacing: .065em; font-size: .75rem; font-weight: 600; text-transform: uppercase; }
.network-head h2, .venues-card h2 { font-size: 1.2rem; letter-spacing: -.035em; font-weight: 600; margin: 5px 0 0; }
.metric-switch { display: flex; gap: 2px; background: #eff2f4; padding: 3px; border-radius: 7px; }
.metric-switch label { cursor: pointer; flex: 1; text-align: center; }
.metric-switch span { display: block; min-height: 34px; padding: 8px 10px; font-size: .8125rem; white-space: nowrap; color: #687780; border-radius: 5px; }
.metric-switch label:has([data-state="checked"]) span { color: #17332b; background: #fff; box-shadow: 0 1px 5px #20314012; font-weight: 600; }
.metric-switch label:has(:focus-visible) { outline: 2px solid #119b79; outline-offset: 3px; border-radius: 5px; }
.legend { display: flex; flex-wrap: wrap; gap: 8px 14px; padding: 0 22px 12px; color: #707b88; font-size: .75rem; }
.legend span { display: inline-flex; align-items: center; gap: 5px; white-space: nowrap; }
.legend i, .asset-dot { width: 7px; height: 7px; flex: 0 0 7px; border-radius: 50%; }
.diagram { position: relative; background: radial-gradient(ellipse at 50% 45%, #fff 10%, #f9fbfc 100%); border-top: 1px solid #edf0f3; }
.diagram::before { content: ""; position: absolute; inset: 0; background-image: radial-gradient(#748d9f20 .65px, transparent .65px); background-size: 16px 16px; pointer-events: none; }
.diagram svg { display: block; width: 100%; height: auto; aspect-ratio: 1000/600; position: relative; touch-action: pan-y; }
.diagram svg.is-zoomed { touch-action: none; cursor: grab; }
.diagram svg.is-zoomed:active { cursor: grabbing; }
.diagram-mobile { display: none; }
.diagram-desktop > svg { height: clamp(420px, calc(100dvh - 390px), 620px); aspect-ratio: auto; }
.edge { transition: opacity .18s; }
.muted-edge { opacity: .09; }
.route-flow { animation: flow 1.4s linear infinite; stroke-linecap: round; }
.node { cursor: pointer; outline: none; transition: opacity .18s; }
.node-body { filter: drop-shadow(0 2px 2px #18304814); transition: r .3s, fill .2s; }
.node:focus-visible .node-ring { stroke-width: 3px; stroke: #263d4c; opacity: 1; }
.muted-node { opacity: .36; }
.ticker { font-family: var(--font-sans); font-size: 15px; font-weight: 680; fill: #263443; paint-order: stroke; stroke: #fff; stroke-width: 4px; stroke-linejoin: round; pointer-events: none; }
.ticker-inside { stroke: none; fill: #030b10; font-size: 14px; font-weight: 750; }
.graph-controls { position: absolute; right: 12px; bottom: 12px; display: flex; padding: 3px; background: #ffffffeb; border: 1px solid #dde5eb; border-radius: 8px; box-shadow: 0 2px 6px #21384f06; }
.graph-controls button { width: 32px; height: 32px; border-radius: 5px; color: #637889; }
.graph-controls svg { width: 14px; height: 14px; aspect-ratio: auto; }
.graph-caption { position: absolute; bottom: 15px; left: 17px; display: flex; align-items: center; gap: 8px; min-height: 32px; padding: 0 10px; max-width: calc(100% - 155px); background: #ffffffde; color: #73818e; font-size: .75rem; border-radius: 6px; }
.graph-caption b { color: #293c49; }
.caption-cross { color: #a1afba; font-size: 20px; line-height: 1; font-weight: 300; }
.graph-caption a, .graph-caption button { display: grid; place-items: center; width: 26px; height: 26px; border: 0; background: transparent; border-radius: 4px; }
.graph-caption svg { width: 15px; height: 15px; aspect-ratio: auto; }
.network-key { display: flex; align-items: center; gap: 10px 18px; flex-wrap: wrap; padding: 12px 20px; border-top: 1px solid #e9eef2; font-size: .75rem; color: #667986; }
.network-key > span { display: flex; align-items: center; gap: 6px; }
.edge-swatch { display: inline-block; width: 20px; height: 3px; border-radius: 3px; background: #d74c9b; }
.edge-swatch.same { background: #12a684; }
.network-key small { color: #89949d; font-size: .75rem; margin-left: auto; }
.focus-card { padding: 20px; min-width: 0; scroll-margin-top: 18px; }
.focus-header { display: flex; align-items: center; justify-content: space-between; min-height: 20px; gap: 8px; }
.focus-header button { display: grid; place-items: center; width: 28px; height: 28px; background: #f1f4f6; color: #617583; border: 0; border-radius: 5px; }
.focus-header svg { width: 14px; height: 14px; }
.focus-title { display: flex; align-items: center; gap: 13px; margin-top: 20px; }
.focus-token { display: grid; place-items: center; width: 44px; height: 44px; flex: 0 0 44px; border-radius: 11px; font-size: .8125rem; font-weight: 750; }
.focus-title h2 { margin: 0; font-size: 1.9rem; letter-spacing: -.045em; line-height: 1; font-weight: 600; overflow-wrap: anywhere; }
.focus-title p { font-size: .8125rem; line-height: 1.4; color: #7e8993; margin: 5px 0 0; }
.contract-link { display: inline-flex; align-items: center; gap: 3px; color: #7a8a96; font: .75rem ui-monospace, monospace; margin-top: 12px; }
.contract-link:hover { color: #0c8b69; }
.contract-link svg { width: 12px; height: 12px; }
.focus-grid { display: grid; grid-template-columns: 1fr 1fr; gap: 21px 15px; margin-top: 20px; padding: 20px 0; border-block: 1px solid #e9edf0; }
.focus-grid span { display: block; font-size: .75rem; color: #798692; }
.focus-grid strong { display: block; font-size: 1.2rem; font-weight: 580; letter-spacing: -.035em; margin-top: 5px; font-variant-numeric: tabular-nums; }
.routes-head { display: flex; align-items: baseline; justify-content: space-between; margin: 22px 0 5px; gap: 8px; }
.routes-head h3 { font-size: .875rem; font-weight: 630; margin: 0; }
.routes-head > span { font-size: .75rem; color: #84929c; }
.routes button { display: block; width: 100%; text-align: left; padding: 12px 0 11px; border: 0; border-bottom: 1px solid #f0f2f4; background: transparent; color: inherit; }
.routes button:hover { background: #f8fbfb; }
.route-main { display: flex; justify-content: space-between; gap: 8px; font-size: .8125rem; font-weight: 550; }
.route-main > span { display: flex; align-items: center; gap: 5px; }
.route-main i { display: inline-block; width: 6px; height: 6px; border-radius: 50%; }
.route-main b { font-weight: 400; color: #b2bdc5; }
.route-main strong { font-weight: 600; }
.route-bar { display: block; height: 2px; background: #f0f3f5; border-radius: 2px; margin-top: 7px; }
.route-bar i { display: block; height: 2px; border-radius: 2px; opacity: .6; transition: width .3s; }
.routes small { display: block; color: #87939c; font-size: .75rem; line-height: 1.35; margin-top: 5px; }
.venues-card { display: grid; grid-template-columns: 190px 1fr; gap: 24px; margin-top: 20px; padding: 20px 22px; }
.venues-card p { margin: 5px 0 0; font-size: .8125rem; color: #84919a; }
.venues { display: grid; grid-template-columns: repeat(auto-fit, minmax(90px, 1fr)); gap: 18px; align-content: center; }
.venues > div { position: relative; display: flex; flex-direction: column; align-items: flex-start; min-width: 0; padding-bottom: 8px; }
.venues > div::after { content: ""; position: absolute; bottom: 0; width: 100%; height: 2px; background: #eef2f4; }
.venues span { color: #637582; font-size: .8125rem; line-height: 1.3; }
.venues strong { font-size: 1.1rem; letter-spacing: -.035em; font-weight: 590; margin-top: 6px; }
.venues small { font-size: .75rem; color: #8a969f; margin-top: 2px; }
.venues i { position: absolute; bottom: 0; z-index: 1; height: 2px; background: #18a17d; }
.methodology { border-bottom: 1px solid #dce3e7; padding: 17px 2px; margin-top: 2px; color: #60727f; }
.methodology summary { display: flex; justify-content: space-between; gap: 14px; align-items: center; list-style: none; cursor: pointer; font-size: .875rem; }
.methodology summary::-webkit-details-marker { display: none; }
.methodology summary > span:last-child { display: flex; align-items: center; gap: 12px; color: #7b8b97; font-size: .75rem; }
.methodology summary svg { width: 14px; height: 14px; transition: transform .2s; }
.methodology[open] summary svg { transform: rotate(180deg); }
.methodology p { max-width: 980px; margin: 16px 0 8px; font-size: .9375rem; line-height: 1.7; color: #637380; }
.methodology a { display: inline-flex; align-items: center; gap: 6px; font-size: .8125rem; color: #138466; }
.methodology a svg { width: 14px; height: 14px; }
footer { display: grid; grid-template-columns: 1fr auto; align-items: start; gap: 18px; padding-top: 20px; }
footer p { font-size: .75rem; margin: 0 0 5px; color: #7b8994; }
footer > div > span { font-size: .75rem; color: #8a97a0; }
.footer-links { display: flex; flex-wrap: wrap; gap: 8px 18px; }
.footer-links a { display: inline-flex; align-items: center; gap: 5px; min-height: 28px; font-size: .75rem; color: #6a7f8d; }
.footer-links svg { width: 12px; height: 12px; }
footer a:hover { color: #0e9873; }
.locale-links { grid-column: 1 / -1; display: flex; flex-wrap: wrap; gap: 8px 20px; }
.locale-links a { font-size: .75rem; color: #82929d; min-height: 28px; }
.locale-links a[aria-current="page"] { color: #208169; }
/* Secondary text remains legible on both paper and card surfaces. */
.feed-state time, .metric small, .license-tag, .section-kicker, .legend,
.graph-caption, .network-key, .network-key small, .focus-title p,
.contract-link, .focus-grid span, .routes-head > span, .routes small,
.venues-card p, .venues small, .methodology summary > span:last-child,
footer p, footer > div > span, .footer-links a, .locale-links a { color: var(--muted-foreground); }
.spin { animation: spin .9s linear infinite; }
@keyframes spin { to { transform: rotate(360deg); } }
@keyframes flow { to { stroke-dashoffset: -30; } }

@media (min-width: 1450px) {
  .workspace { grid-template-columns: minmax(0, 1fr) 330px; }
  .focus-card { padding: 24px; }
  .focus-grid { gap: 25px 15px; padding: 24px 0; }
  .routes button { padding-block: 15px; }
}
@media (max-width: 1150px) {
  .shell { width: calc(100% - 40px); }
  .workspace { grid-template-columns: minmax(0, 1fr) 270px; gap: 14px; }
  .network-head { flex-wrap: wrap; padding: 18px 18px 10px; }
  .network-head .section-kicker { display: none; }
  .network-head h2 { margin: 0; font-size: 1.05rem; }
  .legend { padding-inline: 18px; }
  .focus-card { padding: 17px; }
  .venues-card { grid-template-columns: 150px 1fr; }
  .venues { grid-template-columns: repeat(5, 1fr); }
  .network-key small { margin-left: 0; }
}
@media (max-width: 850px) {
  .shell { width: calc(100% - 32px); padding-top: 22px; }
  .topbar { gap: 16px; }
  .identity { gap: 10px; }
  .identity p { font-size: .6875rem; letter-spacing: .05em; }
  .brand-mark { flex-basis: 35px; transform: scale(.85); transform-origin: left center; margin-right: 0; }
  .identity h1 { font-size: 1.7rem; }
  .language-trigger { min-width: 100px; max-width: 116px; }
  .workspace { grid-template-columns: minmax(0, 1fr); }
  .network-head { flex-wrap: nowrap; }
  .network-head .section-kicker { display: block; }
  .network-head h2 { margin-top: 5px; }
  .focus-card { display: grid; grid-template-columns: .8fr 1.2fr; gap: 0 28px; }
  .focus-header, .focus-title, .contract-link, .focus-grid { grid-column: 1; }
  .focus-title { margin-top: 16px; }
  .focus-grid { border-bottom: 0; margin-top: 14px; padding-bottom: 0; }
  .routes-head { grid-column: 2; grid-row: 1; margin: 0; }
  .routes { grid-column: 2; grid-row: 2 / span 4; }
  .venues-card { grid-template-columns: 1fr; gap: 18px; }
  .venues { grid-template-columns: repeat(5, 1fr); }
  footer { grid-template-columns: 1fr; gap: 12px; }
}
@media (max-width: 600px) {
  .chain-row { gap: 9px 12px; padding-top: 12px; }
  .chain-trigger { width: 142px !important; }
  .coverage-label { flex: 1; min-width: 120px; font-size: .75rem; line-height: 1.4; }
  .refresh-result:not(:empty) { flex-basis: 100%; text-align: left; }
  .shell { width: calc(100% - 24px); padding: 18px 0 18px; }
  .topbar { flex-wrap: wrap; padding: 0 2px 15px; gap: 14px 8px; }
  .identity { gap: 8px; }
  .identity p { font-size: .6875rem; margin-bottom: 5px; }
  .identity p span { margin-inline: 5px; }
  .identity h1 { font-size: 1.9rem; }
  .top-actions { justify-content: flex-end; width: 100%; gap: 4px; }
  .feed-state { flex-direction: row; align-items: center; gap: 8px; margin-right: auto; flex-wrap: wrap; }
  .feed-state time { font-size: .75rem; }
  .language-trigger { min-width: 108px; max-width: 130px; height: 36px !important; font-size: .8125rem !important; }
  .refresh-button { height: 36px; width: 36px; }
  .live-badge { font-size: .75rem; }
  .metrics { gap: 16px 0; padding: 17px 2px 16px; grid-template-columns: 1.1fr 1.1fr .8fr; }
  .metric { padding-left: 14px; }
  .metric:nth-child(3) { display: none; }
  .metric strong { font-size: 1.65rem; margin: 7px 0 0; }
  .metric strong svg { display: none; }
  .metric > span { font-size: .75rem; }
  .metric small { display: none; }
  .fork-bar { min-height: 40px; gap: 9px; margin-bottom: 14px; padding-left: 10px; }
  .fork-label { font-size: .75rem; gap: 5px; }
  .fork-label svg { width: 13px; height: 13px; }
  .license-tag { display: none; }
  .fork-bar code { font-size: .6875rem; padding-block: 9px; }
  .fork-bar button { min-width: 32px; height: 32px; padding: 0 7px; }
  .fork-bar button span { display: none; }
  .workspace { gap: 14px; }
  .network-card, .focus-card, .venues-card { border-radius: 11px; }
  .network-head { padding: 15px 13px 10px; gap: 8px; }
  .network-head .section-kicker { display: none; }
  .network-head h2 { margin: 0; font-size: .9375rem; letter-spacing: -.02em; }
  .metric-switch span { padding: 8px; min-height: 34px; font-size: .75rem; }
  .legend { padding: 0 13px 11px; gap: 7px 12px; font-size: .75rem; }
  .diagram-desktop { display: none; }
  .diagram-mobile { display: block; }
  .diagram-mobile > svg { aspect-ratio: 390/570; }
  .diagram-mobile .ticker { font-size: 14px; stroke-width: 3.5px; }
  .diagram-mobile .ticker-inside { font-size: 12px; stroke: none; }
  .graph-controls { right: 9px; bottom: 9px; padding: 2px; }
  .graph-controls button { width: 32px; height: 36px; }
  .graph-caption { bottom: 11px; left: 9px; padding-inline: 6px; max-width: calc(100% - 126px); min-height: 36px; font-size: .75rem; gap: 6px; line-height: 1.3; }
  .graph-caption .caption-cross { display: none; }
  .graph-caption a, .graph-caption button { width: 24px; flex: 0 0 24px; }
  .graph-caption span:not(.asset-dot) { display: none; }
  .network-key { padding: 11px 13px; gap: 9px 13px; font-size: .75rem; }
  .network-key small { width: 100%; }
  .focus-card { display: block; padding: 18px; }
  .focus-title { margin-top: 17px; }
  .focus-grid { grid-template-columns: repeat(4, 1fr); gap: 8px; margin-top: 15px; padding-block: 16px; border-bottom: 1px solid #e9edf0; }
  .focus-grid span { font-size: .75rem; }
  .focus-grid strong { font-size: 1rem; margin-top: 6px; }
  .routes-head { margin-top: 18px; }
  .routes button { padding-block: 14px; }
  .route-main { font-size: .875rem; }
  .venues-card { padding: 18px; margin-top: 14px; }
  .venues-card h2 { font-size: 1.1rem; }
  .venues { grid-template-columns: repeat(3, 1fr); gap: 18px; }
  .methodology { padding-block: 17px; }
  .methodology summary > span:last-child { font-size: .75rem; }
  .methodology p { font-size: .9375rem; }
  .footer-links a, .locale-links a { min-height: 34px; }
}
@media (max-width: 370px) {
  .identity h1 { font-size: 1.65rem; }
  .network-head { flex-wrap: wrap; }
  .network-head h2 { width: 100%; }
  .metric-switch { width: 100%; }
  .metric strong { font-size: 1.4rem; }
  .focus-grid { grid-template-columns: 1fr 1fr; gap: 15px; }
}
@media (prefers-reduced-motion: reduce) {
  html { scroll-behavior: auto; }
  *, *::before, *::after { animation: none !important; transition: none !important; }
}

.chain-mark.chain-ethereum { color: #465171; background: #e7ebf4; }
.chain-mark.chain-base { color: #fff; background: #1652f0; }
